@@ -42,11 +42,11 @@ App::Pod - Quickly show available class methods and documentation.
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 
 =head1 SYNOPSIS
@@ -162,13 +162,13 @@ sub _define_spec {
             handler     => "_show_help",
         },
         {
-            spec        => "list_tool_options|lto",
+            spec        => "tool_options|to",
             description => "List tool options.",
             handler     => "list_tool_options",
         },
         {
-            spec        => "list_class_options|lco",
-            description => "List class events and methods.",
+            spec        => "class_options|co",
+            description => "Class events and methods.",
             handler     => "list_class_options",
         },
         {
@@ -178,11 +178,11 @@ sub _define_spec {
         },
         {
             spec        => "dump|dd",
-            description => "Dump additional information.",
+            description => "Dump extra info.",
         },
         {
             spec        => "doc|d",
-            description => "View the class documentation.",
+            description => "View class documentation.",
             handler     => "doc_class",
         },
         {
@@ -247,31 +247,31 @@ sub _define_help_template {
     ##_grey:Shows available class methods and documentation
 
     ##_neon:Syntax:
-        <SCRIPT> module_name [method_name]
+      <SCRIPT> module_name [method_name]
 
     ##_neon:Options:
-        <OPTIONS>
+      <OPTIONS>
 
     ##_neon:Examples:
-        ##_grey:# Methods
-        <SCRIPT> Mojo::UserAgent
-        <SCRIPT> Mojo::UserAgent -a
+      ##_grey:# Methods
+      <SCRIPT> Mojo::UserAgent
+      <SCRIPT> Mojo::UserAgent -a
 
-        ##_grey:# Method
-        <SCRIPT> Mojo::UserAgent prepare
+      ##_grey:# Method
+      <SCRIPT> Mojo::UserAgent prepare
 
-        ##_grey:# Documentation
-        <SCRIPT> Mojo::UserAgent -d
+      ##_grey:# Documentation
+      <SCRIPT> Mojo::UserAgent -d
 
-        ##_grey:# Edit
-        <SCRIPT> Mojo::UserAgent -e
-        <SCRIPT> Mojo::UserAgent prepare -e
+      ##_grey:# Edit
+      <SCRIPT> Mojo::UserAgent -e
+      <SCRIPT> Mojo::UserAgent prepare -e
 
-        ##_grey:# List all methods
-        <SCRIPT> Mojo::UserAgent --list_class_options
+      ##_grey:# List all methods
+      <SCRIPT> Mojo::UserAgent --class_options
 
-        ##_grey:# List all Module::Build actions.
-        <SCRIPT> Module::Build --query head1=ACTIONS/item-text
+      ##_grey:# List all Module::Build actions.
+      <SCRIPT> Module::Build --query head1=ACTIONS/item-text
     HELP
 }
 
@@ -306,10 +306,11 @@ sub _build_help_options {
         [ $colored_opt, _grey( $desc ), length $colored_opt ];
     } _define_spec();
 
-    my $max = max map { $_->[2] } @all;
+    my $max    = max map { $_->[2] } @all;
+    my $indent = " " x 2;
 
     my $options =
-      join "\n    ",
+      join "\n$indent",
       map { sprintf "%-${max}s - %s", @$_[ 0, 1 ] } @all;
 
     $options;
@@ -345,7 +346,7 @@ sub list_class_options {
     if ( not $self->class ) {
         say "";
         say _red( "Missing class name!" );
-        say "";
+        say _reset( "" );
         return;
     }
 
@@ -455,7 +456,7 @@ sub _class_error {
     if ( $class !~ / ^ [ \w_: ]+ $ /x ) {
         say "";
         say _red( "Invalid class name: $class" );
-        say "";
+        say _reset( "" );
         return 1;
     }
 
@@ -505,7 +506,7 @@ sub show_header {
     return unless $name and $summary;
 
     _sayt _yellow( $name ) . " - " . _green( $summary );
-    say "";
+    say _reset( "" );
 }
 
 =head2 show_method_doc
@@ -523,6 +524,7 @@ sub show_method_doc {
 
     # Color.
     for ( $doc ) {
+        chomp;
 
         # Headings.
         s/ ^ \s* \K (\S+:) (?= \s* $ ) / _green($1) /xgem;
@@ -532,6 +534,7 @@ sub show_method_doc {
     }
 
     say $doc;
+    say _reset( "" );
 }
 
 =head2 show_inheritance
@@ -561,7 +564,7 @@ sub show_inheritance {
     return if $size <= 1;
     say _neon( "Inheritance ($size):" );
     say _grey( " $_" ) for @tree;
-    say "";
+    say _reset( "" );
 }
 
 #
@@ -612,7 +615,7 @@ sub show_events {
     for ( @names ) {
         _sayt sprintf $format, _green( $_ ), _grey( $events->{$_} );
     }
-    say "";
+    say _reset( "" );
 }
 
 #
@@ -703,7 +706,7 @@ sub show_methods {
 
     say _grey( "\nUse --all (or -a) to see all methods." )
       unless $self->opts->{all};
-    say "";
+    say _reset( "" );
 }
 
 #
@@ -820,6 +823,11 @@ sub _neon {
     colored( "@_", "RESET ON_BRIGHT_BLACK" );
 }
 
+sub _reset {
+
+    colored( "@_", "RESET" );
+}
+
 #
 # Junk
 #
